summaryrefslogtreecommitdiffstats
path: root/views/widget/root_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'views/widget/root_view.h')
-rw-r--r--views/widget/root_view.h16
1 files changed, 10 insertions, 6 deletions
diff --git a/views/widget/root_view.h b/views/widget/root_view.h
index 2f1e391..6488de5 100644
--- a/views/widget/root_view.h
+++ b/views/widget/root_view.h
@@ -144,7 +144,7 @@ class RootView : public View,
virtual View* FindNextFocusableView(View* starting_view,
bool reverse,
Direction direction,
- bool dont_loop,
+ bool check_starting_view,
FocusTraversable** focus_traversable,
View** focus_traversable_view);
virtual FocusTraversable* GetFocusTraversableParent();
@@ -214,22 +214,26 @@ class RootView : public View,
// Returns the next focusable view or view containing a FocusTraversable (NULL
// if none was found), starting at the starting_view.
// skip_starting_view, can_go_up and can_go_down controls the traversal of
// the views hierarchy.
// skip_group_id specifies a group_id, -1 means no group. All views from a
// group are traversed in one pass.
View* FindNextFocusableViewImpl(View* starting_view,
- bool skip_starting_view,
+ bool check_starting_view,
bool can_go_up,
bool can_go_down,
- int skip_group_id);
+ int skip_group_id,
+ FocusTraversable** focus_traversable,
+ View** focus_traversable_view);
// Same as FindNextFocusableViewImpl but returns the previous focusable view.
View* FindPreviousFocusableViewImpl(View* starting_view,
- bool skip_starting_view,
+ bool check_starting_view,
bool can_go_up,
bool can_go_down,
- int skip_group_id);
+ int skip_group_id,
+ FocusTraversable** focus_traversable,
+ View** focus_traversable_view);
// Convenience method that returns true if a view is focusable and does not
// belong to the specified group.
@@ -214,22 +214,26 @@ class RootView : public View,
// Returns the next focusable view or view containing a FocusTraversable (NULL
// if none was found), starting at the starting_view.
- // skip_starting_view, can_go_up and can_go_down controls the traversal of
+ // check_starting_view, can_go_up and can_go_down controls the traversal of
// the views hierarchy.
// skip_group_id specifies a group_id, -1 means no group. All views from a